aind\_behavior\_curriculum package
==================================

Submodules
----------

aind\_behavior\_curriculum.curriculum module
--------------------------------------------

.. autoclass:: aind_behavior_curriculum.curriculum.BehaviorGraph
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

.. autoclass:: aind_behavior_curriculum.curriculum.Metrics
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: aind_behavior_curriculum.curriculum.Rule
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: aind_behavior_curriculum.curriculum.Policy
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: aind_behavior_curriculum.curriculum.PolicyTransition
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: aind_behavior_curriculum.curriculum.Stage
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: aind_behavior_curriculum.curriculum.StageTransition
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: aind_behavior_curriculum.curriculum.StageGraph
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: aind_behavior_curriculum.curriculum.Curriculum
   :members:
   :undoc-members:
   :show-inheritance:

aind\_behavior\_curriculum.curriculum\_utils module
---------------------------------------------------

.. automodule:: aind_behavior_curriculum.curriculum_utils
   :members:
   :undoc-members:
   :show-inheritance:

aind\_behavior\_curriculum.task module
--------------------------------------

.. automodule:: aind_behavior_curriculum.task
   :members:
   :undoc-members:
   :show-inheritance:

aind\_behavior\_curriculum.trainer module
-----------------------------------------

.. automodule:: aind_behavior_curriculum.trainer
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_behavior_curriculum
   :members:
   :undoc-members:
   :show-inheritance:
